# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/dynamic/common/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.dynamic.v2 import dynamic_pb2 as bilibili_dot_app_dot_dynamic_dot_v2_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/dynamic/common/dynamic.proto\x12\x10\x62ilibili.dynamic\x1a%bilibili/app/dynamic/v2/dynamic.proto\"y\n\x07\x41tGroup\x12\x31\n\ngroup_type\x18\x01 \x01(\x0e\x32\x1d.bilibili.dynamic.AtGroupType\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\'\n\x05items\x18\x03 \x03(\x0b\x32\x18.bilibili.dynamic.AtItem\"]\n\x06\x41tItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x04 \x01(\x05\x12\x1c\n\x14official_verify_type\x18\x05 \x01(\x05\"\x18\n\tAtListReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\"6\n\tAtListRsp\x12)\n\x06groups\x18\x01 \x03(\x0b\x32\x19.bilibili.dynamic.AtGroup\"+\n\x0b\x41tSearchReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"+\n\x0e\x42ottomBusiness\x12\x0b\n\x03rid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x03\"f\n\x0e\x43reateActivity\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x16\n\x0e\x61\x63tivity_state\x18\x02 \x01(\x05\x12\x17\n\x0fis_new_activity\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\x05\"\x83\x01\n\x10\x43reateAttachCard\x12\x30\n\x05goods\x18\x01 \x01(\x0b\x32!.bilibili.dynamic.CreateGoodsCard\x12=\n\x0b\x63ommon_card\x18\x02 \x01(\x0b\x32(.bilibili.dynamic.CreateCommonAttachCard\"\x98\x02\n\x0f\x43reateCheckResp\x12\x31\n\x07setting\x18\x01 \x01(\x0b\x32 .bilibili.dynamic.PublishSetting\x12\x32\n\npermission\x18\x02 \x01(\x0b\x32\x1e.bilibili.dynamic.UpPermission\x12\x32\n\nshare_info\x18\x03 \x01(\x0b\x32\x1e.bilibili.dynamic.ShareChannel\x12\x36\n\nyellow_bar\x18\x04 \x01(\x0b\x32\".bilibili.dynamic.PublishYellowBar\x12\x32\n\x0cplus_red_dot\x18\x05 \x01(\x0b\x32\x1c.bilibili.dynamic.PlusRedDot\"\x89\x01\n\x16\x43reateCommonAttachCard\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .bilibili.dynamic.AttachCardType\x12\x0e\n\x06\x62iz_id\x18\x02 \x01(\x03\x12\x16\n\x0ereserve_source\x18\x03 \x01(\x05\x12\x17\n\x0freserve_lottery\x18\x04 \x01(\x05\"F\n\rCreateContent\x12\x35\n\x08\x63ontents\x18\x01 \x03(\x0b\x32#.bilibili.dynamic.CreateContentItem\"\x91\x01\n\x11\x43reateContentItem\x12\x10\n\x08raw_text\x18\x01 \x01(\t\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.bilibili.dynamic.ContentType\x12\x0e\n\x06\x62iz_id\x18\x03 \x01(\t\x12-\n\x05goods\x18\x04 \x01(\x0b\x32\x1e.bilibili.dynamic.GoodsContent\"\x8a\x05\n\x0e\x43reateDynVideo\x12\x15\n\rrelation_from\x18\x01 \x01(\t\x12\x10\n\x08\x62iz_from\x18\x03 \x01(\x05\x12\x11\n\tcopyright\x18\x04 \x01(\x05\x12\x11\n\tno_public\x18\x05 \x01(\x05\x12\x12\n\nno_reprint\x18\x06 \x01(\x05\x12\x0e\n\x06source\x18\x07 \x01(\t\x12\r\n\x05\x63over\x18\x08 \x01(\t\x12\r\n\x05title\x18\t \x01(\t\x12\x0b\n\x03tid\x18\n \x01(\x03\x12\x0b\n\x03tag\x18\x0b \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0c \x01(\t\x12\x16\n\x0e\x64\x65sc_format_id\x18\r \x01(\x03\x12\x11\n\topen_elec\x18\x0e \x01(\x05\x12\r\n\x05\x64time\x18\x0f \x01(\x05\x12\x30\n\x06videos\x18\x10 \x03(\x0b\x32 .bilibili.dynamic.DynVideoMultiP\x12\x36\n\twatermark\x18\x11 \x01(\x0b\x32#.bilibili.dynamic.DynVideoWatermark\x12\x12\n\nmission_id\x18\x12 \x01(\x03\x12\x0f\n\x07\x64ynamic\x18\x13 \x01(\t\x12\x19\n\x11\x64ynamic_extension\x18\x14 \x01(\t\x12\x14\n\x0c\x64ynamic_ctrl\x18\x15 \x01(\t\x12\x14\n\x0c\x64ynamic_from\x18\x16 \x01(\t\x12\x12\n\nlottery_id\x18\x17 \x01(\x03\x12,\n\x04vote\x18\x18 \x01(\x0b\x32\x1e.bilibili.dynamic.DynVideoVote\x12\x1a\n\x12up_selection_reply\x18\x19 \x01(\x08\x12\x16\n\x0eup_close_reply\x18\x1a \x01(\x08\x12\x16\n\x0eup_close_danmu\x18\x1b \x01(\x08\x12\x0f\n\x07up_from\x18\x1c \x01(\x03\x12\x10\n\x08\x64uration\x18\x1d \x01(\x03\"\xb2\x01\n\x14\x43reateDynVideoResult\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x43\n\x10submitact_banner\x18\x03 \x01(\x0b\x32).bilibili.dynamic.DynVideoSubmitActBanner\x12\x37\n\npush_intro\x18\x04 \x01(\x0b\x32#.bilibili.dynamic.DynVideoPushIntro\"\"\n\x0f\x43reateGoodsCard\x12\x0f\n\x07item_id\x18\x01 \x03(\t\"\xf4\x01\n\x0c\x43reateOption\x12\x19\n\x11up_choose_comment\x18\x01 \x01(\x05\x12\x15\n\rclose_comment\x18\x02 \x01(\x05\x12\x14\n\x0c\x66old_exclude\x18\x03 \x01(\x05\x12\x13\n\x0b\x61udit_level\x18\x04 \x01(\x05\x12\x17\n\x0fsync_to_comment\x18\x05 \x01(\x05\x12:\n\x10video_share_info\x18\x06 \x01(\x0b\x32 .bilibili.dynamic.VideoShareInfo\x12\x32\n\x08\x61\x63tivity\x18\x07 \x01(\x0b\x32 .bilibili.dynamic.CreateActivity\"\x87\x01\n\tCreatePic\x12\x0f\n\x07img_src\x18\x01 \x01(\t\x12\x11\n\timg_width\x18\x02 \x01(\x01\x12\x12\n\nimg_height\x18\x03 \x01(\x01\x12\x10\n\x08img_size\x18\x04 \x01(\x01\x12\x30\n\x08img_tags\x18\x05 \x03(\x0b\x32\x1e.bilibili.dynamic.CreatePicTag\"\xea\x01\n\x0c\x43reatePicTag\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x0b\n\x03tid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x13\n\x0btext_string\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\x03\x12\x13\n\x0bsource_type\x18\x07 \x01(\x03\x12\x0b\n\x03url\x18\x08 \x01(\t\x12\x12\n\nschema_url\x18\t \x01(\t\x12\x10\n\x08jump_url\x18\n \x01(\t\x12\x13\n\x0borientation\x18\x0b \x01(\x03\x12\t\n\x01x\x18\x0c \x01(\x03\x12\t\n\x01y\x18\r \x01(\x03\x12\x0b\n\x03poi\x18\x0e \x01(\t\"\xca\x01\n\nCreateResp\x12\x0e\n\x06\x64yn_id\x18\x01 \x01(\x03\x12\x12\n\ndyn_id_str\x18\x02 \x01(\t\x12\x10\n\x08\x64yn_type\x18\x03 \x01(\x03\x12\x0f\n\x07\x64yn_rid\x18\x04 \x01(\x03\x12\x37\n\tfake_card\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v2.DynamicItem\x12<\n\x0cvideo_result\x18\x06 \x01(\x0b\x32&.bilibili.dynamic.CreateDynVideoResult\"\x9b\x01\n\tCreateTag\x12%\n\x03lbs\x18\x01 \x01(\x0b\x32\x18.bilibili.dynamic.ExtLbs\x12\x32\n\x08sdk_game\x18\x02 \x01(\x0b\x32 .bilibili.dynamic.BottomBusiness\x12\x33\n\tdiversion\x18\x03 \x01(\x0b\x32 .bilibili.dynamic.BottomBusiness\"\'\n\x0b\x43reateTopic\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x0b\x44ynIdentity\x12\x0e\n\x06\x64yn_id\x18\x01 \x01(\x03\x12,\n\x07revs_id\x18\x02 \x01(\x0b\x32\x1b.bilibili.dynamic.DynRevsId\"*\n\tDynRevsId\x12\x10\n\x08\x64yn_type\x18\x01 \x01(\x03\x12\x0b\n\x03rid\x18\x02 \x01(\x03\"\x89\x06\n\x0e\x44ynVideoEditor\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0e\n\x06upfrom\x18\x02 \x01(\x05\x12\x0f\n\x07\x66ilters\x18\x03 \x01(\t\x12\r\n\x05\x66onts\x18\x04 \x01(\t\x12\x11\n\tsubtitles\x18\x05 \x01(\t\x12\x0c\n\x04\x62gms\x18\x06 \x01(\t\x12\x10\n\x08stickers\x18\x07 \x01(\t\x12\x18\n\x10videoup_stickers\x18\x08 \x01(\t\x12\r\n\x05trans\x18\t \x01(\t\x12\x0f\n\x07makeups\x18\n \x01(\t\x12\x10\n\x08surgerys\x18\x0b \x01(\t\x12\x10\n\x08videofxs\x18\x0c \x01(\t\x12\x0e\n\x06themes\x18\r \x01(\t\x12\x12\n\ncooperates\x18\x0e \x01(\t\x12\x0f\n\x07rhythms\x18\x0f \x01(\t\x12\x0f\n\x07\x65\x66\x66\x65\x63ts\x18\x10 \x01(\t\x12\x13\n\x0b\x62\x61\x63kgrounds\x18\x11 \x01(\t\x12\x0e\n\x06videos\x18\x12 \x01(\t\x12\x0e\n\x06sounds\x18\x13 \x01(\t\x12\x0f\n\x07\x66lowers\x18\x14 \x01(\t\x12\x17\n\x0f\x63over_templates\x18\x15 \x01(\t\x12\x0b\n\x03tts\x18\x16 \x01(\t\x12\x10\n\x08openings\x18\x17 \x01(\t\x12\x13\n\x0brecord_text\x18\x18 \x01(\x08\x12\x0e\n\x06vupers\x18\x19 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x1a \x01(\t\x12\x15\n\rbcut_features\x18\x1b \x01(\t\x12\x14\n\x0c\x61udio_record\x18\x1c \x01(\x05\x12\x0e\n\x06\x63\x61mera\x18\x1d \x01(\x05\x12\r\n\x05speed\x18\x1e \x01(\x05\x12\x15\n\rcamera_rotate\x18\x1f \x01(\x05\x12\x15\n\rscreen_record\x18  \x01(\x05\x12\x13\n\x0b\x64\x65\x66\x61ult_end\x18! \x01(\x05\x12\x10\n\x08\x64uration\x18\" \x01(\x05\x12\x11\n\tpic_count\x18# \x01(\x05\x12\x13\n\x0bvideo_count\x18$ \x01(\x05\x12\x15\n\rshot_duration\x18% \x01(\x05\x12\x11\n\tshot_game\x18& \x01(\t\x12\x11\n\thighlight\x18\' \x01(\x08\x12\x15\n\rhighlight_cnt\x18( \x01(\x05\x12\x11\n\tpip_count\x18) \x01(\x05\"t\n\x0e\x44ynVideoHotAct\x12\x0e\n\x06\x61\x63t_id\x18\x01 \x01(\x03\x12\r\n\x05\x65time\x18\x02 \x01(\x03\x12\n\n\x02id\x18\x03 \x01(\x03\x12\x0b\n\x03pic\x18\x04 \x01(\t\x12\r\n\x05stime\x18\x05 \x01(\x03\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0c\n\x04link\x18\x07 \x01(\t\"p\n\x0e\x44ynVideoMultiP\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x30\n\x06\x65\x64itor\x18\x04 \x01(\x0b\x32 .bilibili.dynamic.DynVideoEditor\"/\n\x11\x44ynVideoPushIntro\x12\x0c\n\x04show\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\"r\n\x17\x44ynVideoSubmitActBanner\x12\x13\n\x0bhotact_text\x18\x01 \x01(\t\x12\x12\n\nhotact_url\x18\x02 \x01(\t\x12.\n\x04list\x18\x03 \x03(\x0b\x32 .bilibili.dynamic.DynVideoHotAct\"J\n\x0c\x44ynVideoVote\x12\x0f\n\x07vote_id\x18\x01 \x01(\x03\x12\x12\n\nvote_title\x18\x02 \x01(\t\x12\x15\n\rtop_for_reply\x18\x03 \x01(\x05\"B\n\x11\x44ynVideoWatermark\x12\r\n\x05state\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x10\n\x08position\x18\x03 \x01(\x05\"\xac\x01\n\x06\x45xtLbs\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x10\n\x08\x64istance\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x03\x12\x0b\n\x03poi\x18\x04 \x01(\t\x12*\n\x08location\x18\x05 \x01(\x0b\x32\x18.bilibili.dynamic.LbsLoc\x12\x12\n\nshow_title\x18\x06 \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x15\n\rshow_distance\x18\x08 \x01(\t\" \n\x0fGetUidByNameReq\x12\r\n\x05names\x18\x01 \x03(\t\"y\n\x0fGetUidByNameRsp\x12\x39\n\x04uids\x18\x01 \x03(\x0b\x32+.bilibili.dynamic.GetUidByNameRsp.UidsEntry\x1a+\n\tUidsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"E\n\x0cGoodsContent\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x0f\n\x07item_id\x18\x02 \x01(\x03\x12\x0f\n\x07shop_id\x18\x03 \x01(\x03\"\xa3\x01\n\x10LaunchedActivity\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12:\n\nactivities\x18\x02 \x03(\x0b\x32&.bilibili.dynamic.LaunchedActivityItem\x12=\n\tshow_more\x18\x03 \x01(\x0b\x32*.bilibili.dynamic.ShowMoreLaunchedActivity\"Z\n\x14LaunchedActivityItem\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x15\n\ractivity_name\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x63tivity_state\x18\x03 \x01(\x05\"\"\n\x06LbsLoc\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\"\xed\x01\n\x0cMetaDataCtrl\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x62uild\x18\x02 \x01(\t\x12\x10\n\x08mobi_app\x18\x03 \x01(\t\x12\r\n\x05\x62uvid\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\x12\n\nfrom_spmid\x18\x06 \x01(\t\x12\x0c\n\x04\x66rom\x18\x07 \x01(\t\x12\x10\n\x08trace_id\x18\x08 \x01(\t\x12\x15\n\rteenager_mode\x18\t \x01(\x05\x12\x12\n\ncold_start\x18\n \x01(\x05\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x0f\n\x07network\x18\x0c \x01(\x05\x12\n\n\x02ip\x18\r \x01(\t\"&\n\nPlusRedDot\x12\x18\n\x10plus_has_red_dot\x18\x01 \x01(\x03\"\x80\x01\n\x07Program\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x12\n\ntarget_url\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x14\n\x0cprogram_text\x18\x06 \x01(\t\x12\x11\n\tjump_text\x18\x07 \x01(\t\"a\n\x0ePublishSetting\x12\x1c\n\x14min_words_to_article\x18\x01 \x01(\x05\x12\x1c\n\x14max_words_to_article\x18\x02 \x01(\x05\x12\x13\n\x0bupload_size\x18\x03 \x01(\x05\";\n\x10PublishYellowBar\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"j\n\x0fRepostInitCheck\x12\x31\n\nrepost_src\x18\x01 \x01(\x0b\x32\x1d.bilibili.dynamic.DynIdentity\x12\x10\n\x08share_id\x18\x02 \x01(\t\x12\x12\n\nshare_mode\x18\x03 \x01(\x05\"z\n\x0cShareChannel\x12\x14\n\x0cshare_origin\x18\x01 \x01(\t\x12\x0b\n\x03oid\x18\x02 \x01(\t\x12\x0b\n\x03sid\x18\x03 \x01(\t\x12:\n\x0eshare_channels\x18\x04 \x03(\x0b\x32\".bilibili.dynamic.ShareChannelItem\"y\n\x10ShareChannelItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07picture\x18\x02 \x01(\t\x12\x15\n\rshare_channel\x18\x03 \x01(\t\x12/\n\x07reserve\x18\x04 \x01(\x0b\x32\x1e.bilibili.dynamic.ShareReserve\"\xfe\x01\n\x0cShareReserve\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x14\n\x0cqr_code_icon\x18\x03 \x01(\t\x12\x14\n\x0cqr_code_text\x18\x04 \x01(\t\x12\x13\n\x0bqr_code_url\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x07 \x01(\t\x12\x34\n\x06poster\x18\x08 \x01(\x0b\x32$.bilibili.dynamic.ShareReservePoster\x12>\n\x0freserve_lottery\x18\t \x01(\x0b\x32%.bilibili.dynamic.ShareReserveLottery\"1\n\x13ShareReserveLottery\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"@\n\x12ShareReservePoster\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x01\x12\x0e\n\x06height\x18\x03 \x01(\x01\"2\n\x0bShareResult\x12\x14\n\x0cshare_enable\x18\x01 \x01(\x03\x12\r\n\x05toast\x18\x02 \x01(\t\"A\n\x18ShowMoreLaunchedActivity\x12\x13\n\x0b\x62utton_text\x18\x01 \x01(\t\x12\x10\n\x08jump_url\x18\x02 \x01(\t\"\x81\x01\n\x06Sketch\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tdesc_text\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x0e\n\x06\x62iz_id\x18\x04 \x01(\x03\x12\x10\n\x08\x62iz_type\x18\x05 \x01(\x03\x12\x11\n\tcover_url\x18\x06 \x01(\t\x12\x12\n\ntarget_url\x18\x07 \x01(\t\"\xb5\x01\n\x0cUpPermission\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\".bilibili.dynamic.UpPermissionItem\x12=\n\x11launched_activity\x18\x02 \x01(\x0b\x32\".bilibili.dynamic.LaunchedActivity\x12\x33\n\x0cshare_result\x18\x03 \x01(\x0b\x32\x1d.bilibili.dynamic.ShareResult\"\x99\x01\n\x10UpPermissionItem\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x12\n\npermission\x18\x02 \x01(\x05\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x10\n\x08jump_url\x18\x06 \x01(\t\x12\r\n\x05toast\x18\x07 \x01(\t\x12\x13\n\x0bhas_red_dot\x18\x08 \x01(\x03\"~\n\x0eUserCreateMeta\x12\x30\n\x08\x61pp_meta\x18\x01 \x01(\x0b\x32\x1e.bilibili.dynamic.MetaDataCtrl\x12%\n\x03loc\x18\x02 \x01(\x0b\x32\x18.bilibili.dynamic.LbsLoc\x12\x13\n\x0brepost_mode\x18\x03 \x01(\x05\"+\n\x0eVideoShareInfo\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04part\x18\x02 \x01(\x05*\x8e\x01\n\x0b\x41tGroupType\x12\x19\n\x15\x41T_GROUP_TYPE_DEFAULT\x10\x00\x12\x18\n\x14\x41T_GROUP_TYPE_RECENT\x10\x01\x12\x18\n\x14\x41T_GROUP_TYPE_FOLLOW\x10\x02\x12\x16\n\x12\x41T_GROUP_TYPE_FANS\x10\x03\x12\x18\n\x14\x41T_GROUP_TYPE_OTHERS\x10\x04*\x94\x03\n\x0e\x41ttachCardType\x12\x14\n\x10\x41TTACH_CARD_NONE\x10\x00\x12\x15\n\x11\x41TTACH_CARD_GOODS\x10\x01\x12\x14\n\x10\x41TTACH_CARD_VOTE\x10\x02\x12\x13\n\x0f\x41TTACH_CARD_UGC\x10\x03\x12\x18\n\x14\x41TTACH_CARD_ACTIVITY\x10\x04\x12!\n\x1d\x41TTACH_CARD_OFFICIAL_ACTIVITY\x10\x05\x12\x15\n\x11\x41TTACH_CARD_TOPIC\x10\x06\x12\x13\n\x0f\x41TTACH_CARD_OGV\x10\x07\x12\x18\n\x14\x41TTACH_CARD_AUTO_OGV\x10\x08\x12\x14\n\x10\x41TTACH_CARD_GAME\x10\t\x12\x15\n\x11\x41TTACH_CARD_MANGA\x10\n\x12\x1a\n\x16\x41TTACH_CARD_DECORATION\x10\x0b\x12\x15\n\x11\x41TTACH_CARD_MATCH\x10\x0c\x12\x14\n\x10\x41TTACH_CARD_PUGV\x10\r\x12\x17\n\x13\x41TTACH_CARD_RESERVE\x10\x0e\x12\x18\n\x14\x41TTACH_CARD_UP_TOPIC\x10\x0f*\xd3\x01\n\x0b\x43ontentType\x12\x15\n\x11\x43ONTENT_TYPE_NONE\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\x06\n\x02\x41T\x10\x02\x12\x0b\n\x07LOTTERY\x10\x03\x12\x08\n\x04VOTE\x10\x04\x12\t\n\x05TOPIC\x10\x05\x12\t\n\x05GOODS\x10\x06\x12\x06\n\x02\x42V\x10\x07\x12\x06\n\x02\x41V\x10\x08\x12\t\n\x05\x45MOJI\x10\t\x12\x08\n\x04USER\x10\n\x12\x06\n\x02\x43V\x10\x0b\x12\x06\n\x02VC\x10\x0c\x12\x07\n\x03WEB\x10\r\x12\n\n\x06TAOBAO\x10\x0e\x12\x08\n\x04MAIL\x10\x0f\x12\x0e\n\nOGV_SEASON\x10\x10\x12\n\n\x06OGV_EP\x10\x11*\xd1\x01\n\x14\x43reateInitCheckScene\x12#\n\x1f\x43REATE_INIT_CHECK_SCENE_INVALID\x10\x00\x12\"\n\x1e\x43REATE_INIT_CHECK_SCENE_NORMAL\x10\x01\x12\"\n\x1e\x43REATE_INIT_CHECK_SCENE_REPOST\x10\x02\x12!\n\x1d\x43REATE_INIT_CHECK_SCENE_SHARE\x10\x03\x12)\n%CREATE_INIT_CHECK_SCENE_RESERVE_SHARE\x10\x04*\xbd\x02\n\x0b\x43reateScene\x12\x18\n\x14\x43REATE_SCENE_INVALID\x10\x00\x12\x1c\n\x18\x43REATE_SCENE_CREATE_WORD\x10\x01\x12\x1c\n\x18\x43REATE_SCENE_CREATE_DRAW\x10\x02\x12!\n\x1d\x43REATE_SCENE_CREATE_DYN_VIDEO\x10\x03\x12\x17\n\x13\x43REATE_SCENE_REPOST\x10\x04\x12\x1a\n\x16\x43REATE_SCENE_SHARE_BIZ\x10\x05\x12\x1b\n\x17\x43REATE_SCENE_SHARE_PAGE\x10\x06\x12\x1e\n\x1a\x43REATE_SCENE_SHARE_PROGRAM\x10\x07\x12\x1b\n\x17\x43REATE_SCENE_REPLY_SYNC\x10\x08\x12&\n\"CREATE_SCENE_REPLY_CREATE_ACTIVITY\x10\t*F\n\rReserveSource\x12\x16\n\x12RESERVE_SOURCE_NEW\x10\x00\x12\x1d\n\x19RESERVE_SOURCE_ASSOCIATED\x10\x01*\x88\x03\n\x10UpPermissionType\x12\x1b\n\x17UP_PERMISSION_TYPE_NONE\x10\x00\x12\x1e\n\x1aUP_PERMISSION_TYPE_LOTTERY\x10\x01\x12%\n!UP_PERMISSION_TYPE_CLIP_PUBLISHED\x10\x02\x12&\n\"UP_PERMISSION_TYPE_UGC_ATTACH_CARD\x10\x03\x12(\n$UP_PERMISSION_TYPE_GOODS_ATTACH_CARD\x10\x04\x12%\n!UP_PERMISSION_TYPE_CHOOSE_COMMENT\x10\x05\x12&\n\"UP_PERMISSION_TYPE_CONTROL_COMMENT\x10\x06\x12$\n UP_PERMISSION_TYPE_CONTROL_DANMU\x10\x07\x12$\n UP_PERMISSION_TYPE_VIDEO_RESERVE\x10\x08\x12#\n\x1fUP_PERMISSION_TYPE_LIVE_RESERVE\x10\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dynamic.common.dynamic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETUIDBYNAMERSP_UIDSENTRY._options = None
  _GETUIDBYNAMERSP_UIDSENTRY._serialized_options = b'8\001'
  _ATGROUPTYPE._serialized_start=7469
  _ATGROUPTYPE._serialized_end=7611
  _ATTACHCARDTYPE._serialized_start=7614
  _ATTACHCARDTYPE._serialized_end=8018
  _CONTENTTYPE._serialized_start=8021
  _CONTENTTYPE._serialized_end=8232
  _CREATEINITCHECKSCENE._serialized_start=8235
  _CREATEINITCHECKSCENE._serialized_end=8444
  _CREATESCENE._serialized_start=8447
  _CREATESCENE._serialized_end=8764
  _RESERVESOURCE._serialized_start=8766
  _RESERVESOURCE._serialized_end=8836
  _UPPERMISSIONTYPE._serialized_start=8839
  _UPPERMISSIONTYPE._serialized_end=9231
  _ATGROUP._serialized_start=98
  _ATGROUP._serialized_end=219
  _ATITEM._serialized_start=221
  _ATITEM._serialized_end=314
  _ATLISTREQ._serialized_start=316
  _ATLISTREQ._serialized_end=340
  _ATLISTRSP._serialized_start=342
  _ATLISTRSP._serialized_end=396
  _ATSEARCHREQ._serialized_start=398
  _ATSEARCHREQ._serialized_end=441
  _BOTTOMBUSINESS._serialized_start=443
  _BOTTOMBUSINESS._serialized_end=486
  _CREATEACTIVITY._serialized_start=488
  _CREATEACTIVITY._serialized_end=590
  _CREATEATTACHCARD._serialized_start=593
  _CREATEATTACHCARD._serialized_end=724
  _CREATECHECKRESP._serialized_start=727
  _CREATECHECKRESP._serialized_end=1007
  _CREATECOMMONATTACHCARD._serialized_start=1010
  _CREATECOMMONATTACHCARD._serialized_end=1147
  _CREATECONTENT._serialized_start=1149
  _CREATECONTENT._serialized_end=1219
  _CREATECONTENTITEM._serialized_start=1222
  _CREATECONTENTITEM._serialized_end=1367
  _CREATEDYNVIDEO._serialized_start=1370
  _CREATEDYNVIDEO._serialized_end=2020
  _CREATEDYNVIDEORESULT._serialized_start=2023
  _CREATEDYNVIDEORESULT._serialized_end=2201
  _CREATEGOODSCARD._serialized_start=2203
  _CREATEGOODSCARD._serialized_end=2237
  _CREATEOPTION._serialized_start=2240
  _CREATEOPTION._serialized_end=2484
  _CREATEPIC._serialized_start=2487
  _CREATEPIC._serialized_end=2622
  _CREATEPICTAG._serialized_start=2625
  _CREATEPICTAG._serialized_end=2859
  _CREATERESP._serialized_start=2862
  _CREATERESP._serialized_end=3064
  _CREATETAG._serialized_start=3067
  _CREATETAG._serialized_end=3222
  _CREATETOPIC._serialized_start=3224
  _CREATETOPIC._serialized_end=3263
  _DYNIDENTITY._serialized_start=3265
  _DYNIDENTITY._serialized_end=3340
  _DYNREVSID._serialized_start=3342
  _DYNREVSID._serialized_end=3384
  _DYNVIDEOEDITOR._serialized_start=3387
  _DYNVIDEOEDITOR._serialized_end=4164
  _DYNVIDEOHOTACT._serialized_start=4166
  _DYNVIDEOHOTACT._serialized_end=4282
  _DYNVIDEOMULTIP._serialized_start=4284
  _DYNVIDEOMULTIP._serialized_end=4396
  _DYNVIDEOPUSHINTRO._serialized_start=4398
  _DYNVIDEOPUSHINTRO._serialized_end=4445
  _DYNVIDEOSUBMITACTBANNER._serialized_start=4447
  _DYNVIDEOSUBMITACTBANNER._serialized_end=4561
  _DYNVIDEOVOTE._serialized_start=4563
  _DYNVIDEOVOTE._serialized_end=4637
  _DYNVIDEOWATERMARK._serialized_start=4639
  _DYNVIDEOWATERMARK._serialized_end=4705
  _EXTLBS._serialized_start=4708
  _EXTLBS._serialized_end=4880
  _GETUIDBYNAMEREQ._serialized_start=4882
  _GETUIDBYNAMEREQ._serialized_end=4914
  _GETUIDBYNAMERSP._serialized_start=4916
  _GETUIDBYNAMERSP._serialized_end=5037
  _GETUIDBYNAMERSP_UIDSENTRY._serialized_start=4994
  _GETUIDBYNAMERSP_UIDSENTRY._serialized_end=5037
  _GOODSCONTENT._serialized_start=5039
  _GOODSCONTENT._serialized_end=5108
  _LAUNCHEDACTIVITY._serialized_start=5111
  _LAUNCHEDACTIVITY._serialized_end=5274
  _LAUNCHEDACTIVITYITEM._serialized_start=5276
  _LAUNCHEDACTIVITYITEM._serialized_end=5366
  _LBSLOC._serialized_start=5368
  _LBSLOC._serialized_end=5402
  _METADATACTRL._serialized_start=5405
  _METADATACTRL._serialized_end=5642
  _PLUSREDDOT._serialized_start=5644
  _PLUSREDDOT._serialized_end=5682
  _PROGRAM._serialized_start=5685
  _PROGRAM._serialized_end=5813
  _PUBLISHSETTING._serialized_start=5815
  _PUBLISHSETTING._serialized_end=5912
  _PUBLISHYELLOWBAR._serialized_start=5914
  _PUBLISHYELLOWBAR._serialized_end=5973
  _REPOSTINITCHECK._serialized_start=5975
  _REPOSTINITCHECK._serialized_end=6081
  _SHARECHANNEL._serialized_start=6083
  _SHARECHANNEL._serialized_end=6205
  _SHARECHANNELITEM._serialized_start=6207
  _SHARECHANNELITEM._serialized_end=6328
  _SHARERESERVE._serialized_start=6331
  _SHARERESERVE._serialized_end=6585
  _SHARERESERVELOTTERY._serialized_start=6587
  _SHARERESERVELOTTERY._serialized_end=6636
  _SHARERESERVEPOSTER._serialized_start=6638
  _SHARERESERVEPOSTER._serialized_end=6702
  _SHARERESULT._serialized_start=6704
  _SHARERESULT._serialized_end=6754
  _SHOWMORELAUNCHEDACTIVITY._serialized_start=6756
  _SHOWMORELAUNCHEDACTIVITY._serialized_end=6821
  _SKETCH._serialized_start=6824
  _SKETCH._serialized_end=6953
  _UPPERMISSION._serialized_start=6956
  _UPPERMISSION._serialized_end=7137
  _UPPERMISSIONITEM._serialized_start=7140
  _UPPERMISSIONITEM._serialized_end=7293
  _USERCREATEMETA._serialized_start=7295
  _USERCREATEMETA._serialized_end=7421
  _VIDEOSHAREINFO._serialized_start=7423
  _VIDEOSHAREINFO._serialized_end=7466
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _NetworkType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NetworkTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NetworkType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NT_UNKNOWN: _NetworkType.ValueType  # 0
    """未知"""
    WIFI: _NetworkType.ValueType  # 1
    """WIFI"""
    CELLULAR: _NetworkType.ValueType  # 2
    """蜂窝网络"""
    OFFLINE: _NetworkType.ValueType  # 3
    """未连接"""
    OTHERNET: _NetworkType.ValueType  # 4
    """其他网络"""
    ETHERNET: _NetworkType.ValueType  # 5
    """以太网"""

class NetworkType(_NetworkType, metaclass=_NetworkTypeEnumTypeWrapper):
    """网络类型"""

NT_UNKNOWN: NetworkType.ValueType  # 0
"""未知"""
WIFI: NetworkType.ValueType  # 1
"""WIFI"""
CELLULAR: NetworkType.ValueType  # 2
"""蜂窝网络"""
OFFLINE: NetworkType.ValueType  # 3
"""未连接"""
OTHERNET: NetworkType.ValueType  # 4
"""其他网络"""
ETHERNET: NetworkType.ValueType  # 5
"""以太网"""
global___NetworkType = NetworkType

class _TFType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TFTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TFType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TF_UNKNOWN: _TFType.ValueType  # 0
    """正常计费"""
    U_CARD: _TFType.ValueType  # 1
    """联通卡"""
    U_PKG: _TFType.ValueType  # 2
    """联通包"""
    C_CARD: _TFType.ValueType  # 3
    """移动卡"""
    C_PKG: _TFType.ValueType  # 4
    """移动包"""
    T_CARD: _TFType.ValueType  # 5
    """电信卡"""
    T_PKG: _TFType.ValueType  # 6
    """电信包"""

class TFType(_TFType, metaclass=_TFTypeEnumTypeWrapper):
    """免流类型"""

TF_UNKNOWN: TFType.ValueType  # 0
"""正常计费"""
U_CARD: TFType.ValueType  # 1
"""联通卡"""
U_PKG: TFType.ValueType  # 2
"""联通包"""
C_CARD: TFType.ValueType  # 3
"""移动卡"""
C_PKG: TFType.ValueType  # 4
"""移动包"""
T_CARD: TFType.ValueType  # 5
"""电信卡"""
T_PKG: TFType.ValueType  # 6
"""电信包"""
global___TFType = TFType

@typing_extensions.final
class Network(google.protobuf.message.Message):
    """网络类型标识
    gRPC头部:x-bili-network-bin
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    TF_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    type: global___NetworkType.ValueType
    """网络类型"""
    tf: global___TFType.ValueType
    """免流类型"""
    oid: builtins.str
    """运营商"""
    def __init__(
        self,
        *,
        type: global___NetworkType.ValueType = ...,
        tf: global___TFType.ValueType = ...,
        oid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "tf", b"tf", "type", b"type"]) -> None: ...

global___Network = Network



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/api/player/v1/player.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#bilibili/api/player/v1/player.proto\x12\x16\x62ilibili.api.player.v1\"\x1c\n\x0eHeartbeatReply\x12\n\n\x02ts\x18\x01 \x01(\x03\"\xb8\x04\n\x0cHeartbeatReq\x12\x13\n\x0bserver_time\x18\x01 \x01(\x03\x12\x0f\n\x07session\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0b\n\x03\x63id\x18\x05 \x01(\x03\x12\x0b\n\x03sid\x18\x06 \x01(\t\x12\x0c\n\x04\x65pid\x18\x07 \x01(\x03\x12\x0c\n\x04type\x18\x08 \x01(\t\x12\x10\n\x08sub_type\x18\t \x01(\x05\x12\x0f\n\x07quality\x18\n \x01(\x05\x12\x12\n\ntotal_time\x18\x0b \x01(\x03\x12\x13\n\x0bpaused_time\x18\x0c \x01(\x03\x12\x13\n\x0bplayed_time\x18\r \x01(\x03\x12\x16\n\x0evideo_duration\x18\x0e \x01(\x03\x12\x11\n\tplay_type\x18\x0f \x01(\t\x12\x14\n\x0cnetwork_type\x18\x10 \x01(\x05\x12\x1f\n\x17last_play_progress_time\x18\x11 \x01(\x03\x12\x1e\n\x16max_play_progress_time\x18\x12 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x13 \x01(\x05\x12\x12\n\nfrom_spmid\x18\x14 \x01(\t\x12\r\n\x05spmid\x18\x15 \x01(\t\x12\x13\n\x0b\x65pid_status\x18\x16 \x01(\t\x12\x13\n\x0bplay_status\x18\x17 \x01(\t\x12\x13\n\x0buser_status\x18\x18 \x01(\t\x12\x1a\n\x12\x61\x63tual_played_time\x18\x19 \x01(\x03\x12\x11\n\tauto_play\x18\x1a \x01(\x05\x12\x16\n\x0elist_play_time\x18\x1b \x01(\x03\x12\x18\n\x10\x64\x65tail_play_time\x18\x1c \x01(\x03\x32\x63\n\tHeartbeat\x12V\n\x06Mobile\x12$.bilibili.api.player.v1.HeartbeatReq\x1a&.bilibili.api.player.v1.HeartbeatReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.api.player.v1.player_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HEARTBEATREPLY._serialized_start=63
  _HEARTBEATREPLY._serialized_end=91
  _HEARTBEATREQ._serialized_start=94
  _HEARTBEATREQ._serialized_end=662
  _HEARTBEAT._serialized_start=664
  _HEARTBEAT._serialized_end=763
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/playershared/playershared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/playershared/playershared.proto\x12\x15\x62ilibili.playershared\"\x83\x01\n\x07\x41rcConf\x12\x12\n\nis_support\x18\x01 \x01(\x08\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\x12:\n\rextra_connent\x18\x03 \x01(\x0b\x32#.bilibili.playershared.ExtraContent\x12\x17\n\x0funsupport_scene\x18\x04 \x03(\x05\"B\n\tConfValue\x12\x14\n\nswitch_val\x18\x01 \x01(\x05H\x00\x12\x16\n\x0cselected_val\x18\x02 \x01(\x05H\x00\x42\x07\n\x05value\"B\n\nDeviceConf\x12\x34\n\nconf_value\x18\x01 \x01(\x0b\x32 .bilibili.playershared.ConfValue\"<\n\x0c\x45xtraContent\x12\x16\n\x0e\x64isable_reason\x18\x01 \x01(\t\x12\x14\n\x0c\x64isable_code\x18\x02 \x01(\x04\"A\n\x07History\x12\x10\n\x08progress\x18\x01 \x01(\x04\x12\r\n\x05toast\x18\x02 \x01(\t\x12\x15\n\rlast_play_cid\x18\x03 \x01(\x04\"\xac\x01\n\x0ePlayDeviceConf\x12\x46\n\tarc_confs\x18\x01 \x03(\x0b\x32\x33.bilibili.playershared.PlayDeviceConf.ArcConfsEntry\x1aR\n\rArcConfsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.bilibili.playershared.DeviceConf:\x02\x38\x01\"\x81\x01\n\x06Scheme\x12=\n\x0b\x61\x63tion_type\x18\x01 \x01(\x0e\x32(.bilibili.playershared.Scheme.ActionType\x12\r\n\x05toast\x18\x02 \x01(\t\")\n\nActionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nSHOW_TOAST\x10\x01\"\xc1\x01\n\x06Stream\x12\x36\n\x0bstream_info\x18\x01 \x01(\x0b\x32!.bilibili.playershared.StreamInfo\x12\x36\n\ndash_video\x18\x02 \x01(\x0b\x32 .bilibili.playershared.DashVideoH\x00\x12<\n\rsegment_video\x18\x03 \x01(\x0b\x32#.bilibili.playershared.SegmentVideoH\x00\x42\t\n\x07\x63ontent\"\x90\x03\n\nStreamInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x65rr_code\x18\x04 \x01(\r\x12\x31\n\x05limit\x18\x05 \x01(\x0b\x32\".bilibili.playershared.StreamLimit\x12\x10\n\x08need_vip\x18\x06 \x01(\x08\x12\x12\n\nneed_login\x18\x07 \x01(\x08\x12\x0e\n\x06intact\x18\x08 \x01(\x08\x12\x12\n\nno_rexcode\x18\t \x01(\x08\x12\x11\n\tattribute\x18\n \x01(\x03\x12\x17\n\x0fnew_description\x18\x0b \x01(\t\x12\x14\n\x0c\x64isplay_desc\x18\x0c \x01(\t\x12\x13\n\x0bsuperscript\x18\r \x01(\t\x12\x10\n\x08vip_free\x18\x0e \x01(\x08\x12\x10\n\x08subtitle\x18\x0f \x01(\t\x12-\n\x06scheme\x18\x10 \x01(\x0b\x32\x1d.bilibili.playershared.Scheme\x12\x13\n\x0bsupport_drm\x18\x11 \x01(\x08\"\xa6\x01\n\x08\x44\x61shItem\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x12\n\nbackup_url\x18\x03 \x03(\t\x12\x11\n\tbandwidth\x18\x04 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x05 \x01(\r\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04size\x18\x07 \x01(\x04\x12\x12\n\nframe_rate\x18\x08 \x01(\t\x12\x15\n\rwidevine_pssh\x18\t \x01(\t\"\xe0\x01\n\tDashVideo\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x12\n\nbackup_url\x18\x02 \x03(\t\x12\x11\n\tbandwidth\x18\x03 \x01(\r\x12\x0f\n\x07\x63odecid\x18\x04 \x01(\r\x12\x0b\n\x03md5\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x10\n\x08\x61udio_id\x18\x07 \x01(\r\x12\x12\n\nno_rexcode\x18\x08 \x01(\x08\x12\x12\n\nframe_rate\x18\t \x01(\t\x12\r\n\x05width\x18\n \x01(\x05\x12\x0e\n\x06height\x18\x0b \x01(\x05\x12\x15\n\rwidevine_pssh\x18\x0c \x01(\t\"C\n\x0cSegmentVideo\x12\x33\n\x07segment\x18\x01 \x03(\x0b\x32\".bilibili.playershared.ResponseUrl\"h\n\x0bResponseUrl\x12\r\n\x05order\x18\x01 \x01(\r\x12\x0e\n\x06length\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\x04\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x12\n\nbackup_url\x18\x05 \x03(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\"n\n\x0cResponseDash\x12.\n\x05video\x18\x01 \x03(\x0b\x32\x1f.bilibili.playershared.DashItem\x12.\n\x05\x61udio\x18\x02 \x03(\x0b\x32\x1f.bilibili.playershared.DashItem\"6\n\x0bStreamLimit\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\"\xd6\x01\n\x08VideoVod\x12\x0b\n\x03\x61id\x18\x01 \x01(\x05\x12\x0b\n\x03\x63id\x18\x02 \x01(\x05\x12\n\n\x02qn\x18\x03 \x01(\x04\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12:\n\x11prefer_codec_type\x18\t \x01(\x0e\x32\x1f.bilibili.playershared.CodeType\x12\x15\n\rvoice_balance\x18\n \x01(\x04\"\xdf\x02\n\x07VodInfo\x12\x0f\n\x07quality\x18\x01 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x12\n\ntimelength\x18\x03 \x01(\x04\x12\x15\n\rvideo_codecid\x18\x04 \x01(\r\x12\x32\n\x0bstream_list\x18\x05 \x03(\x0b\x32\x1d.bilibili.playershared.Stream\x12\x33\n\ndash_audio\x18\x06 \x03(\x0b\x32\x1f.bilibili.playershared.DashItem\x12/\n\x05\x64olby\x18\x07 \x01(\x0b\x32 .bilibili.playershared.DolbyItem\x12\x31\n\x06volume\x18\x08 \x01(\x0b\x32!.bilibili.playershared.VolumeInfo\x12;\n\x0eloss_less_item\x18\t \x01(\x0b\x32#.bilibili.playershared.LossLessItem\"\x99\x01\n\tDolbyItem\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.bilibili.playershared.DolbyItem.Type\x12.\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1f.bilibili.playershared.DashItem\"\'\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\t\n\x05\x41TMOS\x10\x02\"k\n\x0cLossLessItem\x12\x19\n\x11is_lossless_audio\x18\x01 \x01(\x08\x12.\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1f.bilibili.playershared.DashItem\x12\x10\n\x08need_vip\x18\x03 \x01(\x08\"\xa3\x01\n\nVolumeInfo\x12\x12\n\nmeasured_i\x18\x01 \x01(\x01\x12\x14\n\x0cmeasured_lra\x18\x02 \x01(\x01\x12\x13\n\x0bmeasured_tp\x18\x03 \x01(\x01\x12\x1a\n\x12measured_threshold\x18\x04 \x01(\x01\x12\x15\n\rtarget_offset\x18\x05 \x01(\x01\x12\x10\n\x08target_i\x18\x06 \x01(\x01\x12\x11\n\ttarget_tp\x18\x07 \x01(\x01\"\x94\x01\n\x07PlayArc\x12\x34\n\nvideo_type\x18\x01 \x01(\x0e\x32 .bilibili.playershared.VideoType\x12\x0b\n\x03\x61id\x18\x02 \x01(\x04\x12\x0b\n\x03\x63id\x18\x03 \x01(\x04\x12\x39\n\rdrm_tech_type\x18\x04 \x01(\x0e\x32\".bilibili.playershared.DrmTechType\"\xa3\x01\n\x0bPlayArcConf\x12\x43\n\tarc_confs\x18\x01 \x03(\x0b\x32\x30.bilibili.playershared.PlayArcConf.ArcConfsEntry\x1aO\n\rArcConfsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.bilibili.playershared.PlayArc:\x02\x38\x01\"+\n\rQnTrialButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\"\x94\x02\n\x0bQnTrialInfo\x12\x12\n\ntrial_able\x18\x01 \x01(\x08\x12\x17\n\x0fremaining_times\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x13\n\x0btime_length\x18\x04 \x01(\x05\x12\x38\n\x0bstart_toast\x18\x05 \x01(\x0b\x32#.bilibili.playershared.QnTrialToast\x12\x36\n\tend_toast\x18\x06 \x01(\x0b\x32#.bilibili.playershared.QnTrialToast\x12\x42\n\x14quality_open_tip_btn\x18\x08 \x01(\x0b\x32$.bilibili.playershared.QnTrialButton\"R\n\x0cQnTrialToast\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x34\n\x06\x62utton\x18\x02 \x01(\x0b\x32$.bilibili.playershared.QnTrialButton\"4\n\x05\x45vent\x12+\n\x05shake\x18\x01 \x01(\x0b\x32\x1c.bilibili.playershared.Shake\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t*=\n\x08\x43odeType\x12\n\n\x06NOCODE\x10\x00\x12\x0b\n\x07\x43ODE264\x10\x01\x12\x0b\n\x07\x43ODE265\x10\x02\x12\x0b\n\x07\x43ODEAV1\x10\x03*\x9a\x04\n\x08\x43onfType\x12\n\n\x06NoType\x10\x00\x12\x0c\n\x08\x46LIPCONF\x10\x01\x12\x0c\n\x08\x43\x41STCONF\x10\x02\x12\x0c\n\x08\x46\x45\x45\x44\x42\x41\x43K\x10\x03\x12\x0c\n\x08SUBTITLE\x10\x04\x12\x10\n\x0cPLAYBACKRATE\x10\x05\x12\n\n\x06TIMEUP\x10\x06\x12\x10\n\x0cPLAYBACKMODE\x10\x07\x12\r\n\tSCALEMODE\x10\x08\x12\x12\n\x0e\x42\x41\x43KGROUNDPLAY\x10\t\x12\x08\n\x04LIKE\x10\n\x12\x0b\n\x07\x44ISLIKE\x10\x0b\x12\x08\n\x04\x43OIN\x10\x0c\x12\x08\n\x04\x45LEC\x10\r\x12\t\n\x05SHARE\x10\x0e\x12\x0e\n\nSCREENSHOT\x10\x0f\x12\x0e\n\nLOCKSCREEN\x10\x10\x12\r\n\tRECOMMEND\x10\x11\x12\x11\n\rPLAYBACKSPEED\x10\x12\x12\x0e\n\nDEFINITION\x10\x13\x12\x0e\n\nSELECTIONS\x10\x14\x12\x08\n\x04NEXT\x10\x15\x12\n\n\x06\x45\x44ITDM\x10\x16\x12\x0f\n\x0bSMALLWINDOW\x10\x17\x12\t\n\x05SHAKE\x10\x18\x12\x0b\n\x07OUTERDM\x10\x19\x12\x0b\n\x07INNERDM\x10\x1a\x12\x0c\n\x08PANORAMA\x10\x1b\x12\t\n\x05\x44OLBY\x10\x1c\x12\x0f\n\x0b\x43OLORFILTER\x10\x1d\x12\x0c\n\x08LOSSLESS\x10\x1e\x12\x0e\n\nFREYAENTER\x10\x1f\x12\x12\n\x0e\x46REYAFULLENTER\x10 \x12\x0c\n\x08SKIPOPED\x10!\x12\x10\n\x0cRECORDSCREEN\x10\"\x12\x0b\n\x07\x44UBBING\x10#\x12\n\n\x06LISTEN\x10$*J\n\x0b\x44rmTechType\x12\x0f\n\x0bUNKNOWN_DRM\x10\x00\x12\r\n\tFAIR_PLAY\x10\x01\x12\r\n\tWIDE_VINE\x10\x02\x12\x0c\n\x08\x42ILI_DRM\x10\x03*1\n\x07PlayErr\x12\t\n\x05NoErr\x10\x00\x12\x1b\n\x17WithMultiDeviceLoginErr\x10\x01*1\n\x0eUnsupportScene\x12\x11\n\rUNKNOWN_SCENE\x10\x00\x12\x0c\n\x08PREMIERE\x10\x01**\n\tVideoType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03UGC\x10\x01\x12\x07\n\x03PGC\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.playershared.playershared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLAYDEVICECONF_ARCCONFSENTRY._options = None
  _PLAYDEVICECONF_ARCCONFSENTRY._serialized_options = b'8\001'
  _PLAYARCCONF_ARCCONFSENTRY._options = None
  _PLAYARCCONF_ARCCONFSENTRY._serialized_options = b'8\001'
  _CODETYPE._serialized_start=3915
  _CODETYPE._serialized_end=3976
  _CONFTYPE._serialized_start=3979
  _CONFTYPE._serialized_end=4517
  _DRMTECHTYPE._serialized_start=4519
  _DRMTECHTYPE._serialized_end=4593
  _PLAYERR._serialized_start=4595
  _PLAYERR._serialized_end=4644
  _UNSUPPORTSCENE._serialized_start=4646
  _UNSUPPORTSCENE._serialized_end=4695
  _VIDEOTYPE._serialized_start=4697
  _VIDEOTYPE._serialized_end=4739
  _ARCCONF._serialized_start=68
  _ARCCONF._serialized_end=199
  _CONFVALUE._serialized_start=201
  _CONFVALUE._serialized_end=267
  _DEVICECONF._serialized_start=269
  _DEVICECONF._serialized_end=335
  _EXTRACONTENT._serialized_start=337
  _EXTRACONTENT._serialized_end=397
  _HISTORY._serialized_start=399
  _HISTORY._serialized_end=464
  _PLAYDEVICECONF._serialized_start=467
  _PLAYDEVICECONF._serialized_end=639
  _PLAYDEVICECONF_ARCCONFSENTRY._serialized_start=557
  _PLAYDEVICECONF_ARCCONFSENTRY._serialized_end=639
  _SCHEME._serialized_start=642
  _SCHEME._serialized_end=771
  _SCHEME_ACTIONTYPE._serialized_start=730
  _SCHEME_ACTIONTYPE._serialized_end=771
  _STREAM._serialized_start=774
  _STREAM._serialized_end=967
  _STREAMINFO._serialized_start=970
  _STREAMINFO._serialized_end=1370
  _DASHITEM._serialized_start=1373
  _DASHITEM._serialized_end=1539
  _DASHVIDEO._serialized_start=1542
  _DASHVIDEO._serialized_end=1766
  _SEGMENTVIDEO._serialized_start=1768
  _SEGMENTVIDEO._serialized_end=1835
  _RESPONSEURL._serialized_start=1837
  _RESPONSEURL._serialized_end=1941
  _RESPONSEDASH._serialized_start=1943
  _RESPONSEDASH._serialized_end=2053
  _STREAMLIMIT._serialized_start=2055
  _STREAMLIMIT._serialized_end=2109
  _VIDEOVOD._serialized_start=2112
  _VIDEOVOD._serialized_end=2326
  _VODINFO._serialized_start=2329
  _VODINFO._serialized_end=2680
  _DOLBYITEM._serialized_start=2683
  _DOLBYITEM._serialized_end=2836
  _DOLBYITEM_TYPE._serialized_start=2797
  _DOLBYITEM_TYPE._serialized_end=2836
  _LOSSLESSITEM._serialized_start=2838
  _LOSSLESSITEM._serialized_end=2945
  _VOLUMEINFO._serialized_start=2948
  _VOLUMEINFO._serialized_end=3111
  _PLAYARC._serialized_start=3114
  _PLAYARC._serialized_end=3262
  _PLAYARCCONF._serialized_start=3265
  _PLAYARCCONF._serialized_end=3428
  _PLAYARCCONF_ARCCONFSENTRY._serialized_start=3349
  _PLAYARCCONF_ARCCONFSENTRY._serialized_end=3428
  _QNTRIALBUTTON._serialized_start=3430
  _QNTRIALBUTTON._serialized_end=3473
  _QNTRIALINFO._serialized_start=3476
  _QNTRIALINFO._serialized_end=3752
  _QNTRIALTOAST._serialized_start=3754
  _QNTRIALTOAST._serialized_end=3836
  _EVENT._serialized_start=3838
  _EVENT._serialized_end=3890
  _SHAKE._serialized_start=3892
  _SHAKE._serialized_end=3913
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/interfaces/v1/search.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/app/interfaces/v1/search.proto\x12\x19\x62ilibili.app.interface.v1\"\x9e\x01\n\x11\x44\x65\x66\x61ultWordsReply\x12\x0f\n\x07trackid\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\t\x12\x0c\n\x04show\x18\x03 \x01(\t\x12\x0c\n\x04word\x18\x04 \x01(\t\x12\x12\n\nshow_front\x18\x05 \x01(\x03\x12\x0f\n\x07\x65xp_str\x18\x06 \x01(\t\x12\x0c\n\x04goto\x18\x07 \x01(\t\x12\r\n\x05value\x18\x08 \x01(\t\x12\x0b\n\x03uri\x18\t \x01(\t\"E\n\x0bNftFaceIcon\x12\x13\n\x0bregion_type\x18\x01 \x01(\x05\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x13\n\x0bshow_status\x18\x03 \x01(\x05\"\xbc\x01\n\x0f\x44\x65\x66\x61ultWordsReq\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\x13\n\x0blogin_event\x18\x02 \x01(\x03\x12\x16\n\x0eteenagers_mode\x18\x03 \x01(\x05\x12\x14\n\x0clessons_mode\x18\x04 \x01(\x05\x12\x0b\n\x03tab\x18\x05 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\t\x12\r\n\x05query\x18\x08 \x01(\t\x12\n\n\x02\x61n\x18\t \x01(\x03\x12\x10\n\x08is_fresh\x18\n \x01(\x03\"o\n\x16SuggestionResult3Reply\x12\x0f\n\x07trackid\x18\x01 \x01(\t\x12\x33\n\x04list\x18\x02 \x03(\x0b\x32%.bilibili.app.interface.v1.ResultItem\x12\x0f\n\x07\x65xp_str\x18\x03 \x01(\t\"R\n\x14SuggestionResult3Req\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x11\n\thighlight\x18\x02 \x01(\x05\x12\x16\n\x0eteenagers_mode\x18\x03 \x01(\x05\"\xf4\x04\n\nResultItem\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07keyword\x18\x03 \x01(\t\x12\x10\n\x08position\x18\x04 \x01(\x05\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x12\n\ncover_size\x18\x06 \x01(\x01\x12\x10\n\x08sug_type\x18\x07 \x01(\t\x12\x11\n\tterm_type\x18\x08 \x01(\x05\x12\x0c\n\x04goto\x18\t \x01(\t\x12\x0b\n\x03uri\x18\n \x01(\t\x12\x42\n\x0fofficial_verify\x18\x0b \x01(\x0b\x32).bilibili.app.interface.v1.OfficialVerify\x12\r\n\x05param\x18\x0c \x01(\t\x12\x0b\n\x03mid\x18\r \x01(\x03\x12\x0c\n\x04\x66\x61ns\x18\x0e \x01(\x05\x12\r\n\x05level\x18\x0f \x01(\x05\x12\x10\n\x08\x61rchives\x18\x10 \x01(\x05\x12\r\n\x05ptime\x18\x11 \x01(\x03\x12\x18\n\x10season_type_name\x18\x12 \x01(\t\x12\x0c\n\x04\x61rea\x18\x13 \x01(\t\x12\r\n\x05style\x18\x14 \x01(\t\x12\r\n\x05label\x18\x15 \x01(\t\x12\x0e\n\x06rating\x18\x16 \x01(\x01\x12\x0c\n\x04vote\x18\x17 \x01(\x05\x12\x36\n\x06\x62\x61\x64ges\x18\x18 \x03(\x0b\x32&.bilibili.app.interface.v1.ReasonStyle\x12\x0e\n\x06styles\x18\x19 \x01(\t\x12\x11\n\tmodule_id\x18\x1a \x01(\x03\x12\x11\n\tlive_link\x18\x1b \x01(\t\x12\x14\n\x0c\x66\x61\x63\x65_nft_new\x18\x1c \x01(\x05\x12=\n\rnft_face_icon\x18\x1d \x01(\x0b\x32&.bilibili.app.interface.v1.NftFaceIcon\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"\xb7\x01\n\x0bReasonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x32\xe2\x01\n\x06Search\x12n\n\x08Suggest3\x12/.bilibili.app.interface.v1.SuggestionResult3Req\x1a\x31.bilibili.app.interface.v1.SuggestionResult3Reply\x12h\n\x0c\x44\x65\x66\x61ultWords\x12*.bilibili.app.interface.v1.DefaultWordsReq\x1a,.bilibili.app.interface.v1.DefaultWordsReply2|\n\nSearchTest\x12n\n\x08NotExist\x12/.bilibili.app.interface.v1.SuggestionResult3Req\x1a\x31.bilibili.app.interface.v1.SuggestionResult3Replyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.interfaces.v1.search_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEFAULTWORDSREPLY._serialized_start=71
  _DEFAULTWORDSREPLY._serialized_end=229
  _NFTFACEICON._serialized_start=231
  _NFTFACEICON._serialized_end=300
  _DEFAULTWORDSREQ._serialized_start=303
  _DEFAULTWORDSREQ._serialized_end=491
  _SUGGESTIONRESULT3REPLY._serialized_start=493
  _SUGGESTIONRESULT3REPLY._serialized_end=604
  _SUGGESTIONRESULT3REQ._serialized_start=606
  _SUGGESTIONRESULT3REQ._serialized_end=688
  _RESULTITEM._serialized_start=691
  _RESULTITEM._serialized_end=1319
  _OFFICIALVERIFY._serialized_start=1321
  _OFFICIALVERIFY._serialized_end=1365
  _REASONSTYLE._serialized_start=1368
  _REASONSTYLE._serialized_end=1551
  _SEARCH._serialized_start=1554
  _SEARCH._serialized_end=1780
  _SEARCHTEST._serialized_start=1782
  _SEARCHTEST._serialized_end=1906
# @@protoc_insertion_point(module_scope)



import time
from hashlib import md5
from typing import Any, Dict, Optional
from urllib.parse import urlencode

from httpx import AsyncClient
from httpx._models import Response
from httpx._types import HeaderTypes, ProxiesTypes, URLTypes

from .._typing import T_Auth
from ..auth import Auth
from ..exceptions import ResponseCodeError

DEFAULT_HEADERS = {
    "user-agent": (
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64)"
        " AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.88"
        " Safari/537.36 Edg/87.0.664.60"
    ),
    "Referer": "https://www.bilibili.com/",
}
APPKEY = "4409e2ce8ffd12b8"
APPSEC = "59b43e04ad6965f34319062b478f83dd"
homepage_cookies: Dict[str, str] = {}


async def get_homepage_cookies(proxies=None):
    if not homepage_cookies:
        async with AsyncClient(proxies=proxies) as client:
            resp = await client.request(
                "GET",
                "https://www.bilibili.com/",
                headers=DEFAULT_HEADERS,
                follow_redirects=True,
            )
        resp.encoding = "utf-8"
        homepage_cookies.update(resp.cookies)
    return homepage_cookies


def _encrypt_params(params: Dict[str, Any], local_id: int = 0) -> Dict[str, Any]:
    params["local_id"] = local_id
    params["appkey"] = APPKEY
    params["ts"] = int(time.time())
    params["sign"] = md5(
        f"{urlencode(sorted(params.items()))}{APPSEC}".encode("utf-8")
    ).hexdigest()
    return params


async def _request(
    method: str,
    url: URLTypes,
    *,
    params: Optional[Dict[str, Any]] = None,
    cookies: Optional[Dict[str, Any]] = None,
    auth: T_Auth = None,
    reqtype: str = "app",
    headers: HeaderTypes = DEFAULT_HEADERS,
    proxies: ProxiesTypes = {"all://": None},
    **kwargs,
) -> Response:
    auth = Auth(auth)
    if params is None:
        params = {}
    if cookies is None:
        cookies = {}
    if reqtype.lower() == "app":
        params.update(auth.tokens)
        _encrypt_params(params)
    else:
        cookies.update(auth.cookies)
    cookies.update(await get_homepage_cookies(proxies))
    async with AsyncClient(proxies=proxies) as client:
        resp = await client.request(
            method, url, headers=headers, params=params, cookies=cookies, **kwargs
        )
    resp.encoding = "utf-8"
    return resp


async def request(
    method: str, url: URLTypes, *, raw: bool = False, **kwargs
) -> Dict[str, Any]:
    raw_json: Dict[str, Any] = (await _request(method, url, **kwargs)).json()
    if raw:
        return raw_json
    if raw_json["code"] != 0:
        raise ResponseCodeError(
            code=raw_json["code"],
            msg=raw_json["message"],
            data=raw_json.get("data", None),
        )
    return raw_json["data"]


async def get(url: URLTypes, **kwargs):
    return await request("GET", url, **kwargs)


async def post(url: URLTypes, **kwargs):
    return await request("POST", url, **kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/ticket/activitygame.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4bilibili/broadcast/message/ticket/activitygame.proto\x12!bilibili.broadcast.message.ticket\"e\n\tRoomEvent\x12\x42\n\x0broom_status\x18\x01 \x01(\x0e\x32-.bilibili.broadcast.message.ticket.RoomStatus\x12\x14\n\x0croom_message\x18\x02 \x01(\t**\n\nRoomStatus\x12\t\n\x05Pause\x10\x00\x12\x08\n\x04Play\x10\x01\x12\x07\n\x03\x45nd\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.ticket.activitygame_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROOMSTATUS._serialized_start=194
  _ROOMSTATUS._serialized_end=236
  _ROOMEVENT._serialized_start=91
  _ROOMEVENT._serialized_end=192
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/dynamic/v1/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/dynamic/v1/dynamic.proto\x12\x17\x62ilibili.app.dynamic.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"{\n\x10\x41\x64\x64ressComponent\x12\x0e\n\x06nation\x18\x01 \x01(\t\x12\x10\n\x08province\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x10\n\x08\x64istrict\x18\x04 \x01(\t\x12\x0e\n\x06street\x18\x05 \x01(\t\x12\x15\n\rstreet_number\x18\x06 \x01(\t\"y\n\x06\x41\x64Info\x12\x13\n\x0bnation_code\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x64\x63ode\x18\x02 \x01(\t\x12\x11\n\tcity_code\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12)\n\x03gps\x18\x05 \x01(\x0b\x32\x1c.bilibili.app.dynamic.v1.Gps\"\x8e\x01\n\rCardCurrBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"\x8d\x01\n\x0e\x43\x61rdCurrSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"\xf6\x03\n\x07\x43\x61rdPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x36\n\nmedia_type\x18\x0b \x01(\x0e\x32\".bilibili.app.dynamic.v1.MediaType\x12\x37\n\x08sub_type\x18\x0c \x01(\x0e\x32%.bilibili.app.dynamic.v1.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x05\x12\x35\n\tdimension\x18\x0e \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x05\x12\x32\n\x06season\x18\x11 \x01(\x0b\x32\".bilibili.app.dynamic.v1.PGCSeason\"\xd5\x02\n\x07\x43\x61rdUGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x36\n\nmedia_type\x18\t \x01(\x0e\x32\".bilibili.app.dynamic.v1.MediaType\x12\x35\n\tdimension\x18\n \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x05\"<\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\r\n\x05\x63olor\x18\x03 \x01(\t\"q\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x31\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v1.DecoCardFan\"^\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\nemoji_type\x18\x04 \x01(\t\x12\x12\n\ngoods_type\x18\x05 \x01(\t\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"\xb4\x01\n\x0b\x44ynamicItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x11\n\titem_type\x18\x02 \x01(\t\x12\x30\n\x07modules\x18\x03 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Module\x12\x12\n\ndyn_id_str\x18\x04 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x05 \x01(\t\x12\x0e\n\x06r_type\x18\x06 \x01(\x05\x12\x10\n\x08has_fold\x18\x07 \x01(\x05\"E\n\x0f\x44ynDetailsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\"\x89\x01\n\rDynDetailsReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64ynamic_ids\x18\x02 \x01(\t\x12\n\n\x02qn\x18\x03 \x01(\x05\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x12\n\nforce_host\x18\x06 \x01(\x05\x12\r\n\x05\x66ourk\x18\x07 \x01(\x05\"P\n\x17\x44ynMixUpListSearchReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v1.MixUpListItem\"%\n\x15\x44ynMixUpListSearchReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"o\n\x19\x44ynMixUpListViewMoreReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v1.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\"\x9d\x01\n\x0e\x44ynOurCityItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12:\n\x07modules\x18\x04 \x03(\x0b\x32).bilibili.app.dynamic.v1.DynOurCityModule\x12\x0b\n\x03rid\x18\x05 \x01(\x03\x12\x12\n\ndebug_info\x18\x06 \x01(\t\"\xd8\x02\n\x10\x44ynOurCityModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x46\n\x0cmodule_cover\x18\x02 \x01(\x0b\x32..bilibili.app.dynamic.v1.DynOurCityModuleCoverH\x00\x12\x44\n\x0bmodule_desc\x18\x03 \x01(\x0b\x32-.bilibili.app.dynamic.v1.DynOurCityModuleDescH\x00\x12H\n\rmodule_author\x18\x04 \x01(\x0b\x32/.bilibili.app.dynamic.v1.DynOurCityModuleAuthorH\x00\x12H\n\rmodule_extend\x18\x05 \x01(\x0b\x32/.bilibili.app.dynamic.v1.DynOurCityModuleExtendH\x00\x42\r\n\x0bmodule_item\"N\n\x16\x44ynOurCityModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"\xf1\x01\n\x15\x44ynOurCityModuleCover\x12\x0e\n\x06\x63overs\x18\x01 \x03(\t\x12\r\n\x05style\x18\x02 \x01(\x05\x12\x19\n\x11\x63over_left_icon_1\x18\x03 \x01(\x05\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x05 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x06 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x07 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x08 \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"$\n\x14\x44ynOurCityModuleDesc\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\t\"z\n\x16\x44ynOurCityModuleExtend\x12\x0c\n\x04type\x18\x01 \x01(\t\x12H\n\nextend_lbs\x18\x02 \x01(\x0b\x32\x32.bilibili.app.dynamic.v1.DynOurCityModuleExtendLBSH\x00\x42\x08\n\x06\x65xtend\"W\n\x19\x44ynOurCityModuleExtendLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"\xca\x01\n\x0f\x44ynOurCityReply\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x10\n\x08has_more\x18\x02 \x01(\x05\x12\r\n\x05style\x18\x03 \x01(\x05\x12\x11\n\ttop_label\x18\x04 \x01(\t\x12\x35\n\x04list\x18\x05 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.DynOurCityItem\x12\x18\n\x10top_button_label\x18\x06 \x01(\t\x12\x0f\n\x07\x63ity_id\x18\x07 \x01(\x05\x12\x11\n\tcity_name\x18\x08 \x01(\t\"\x8b\x03\n\rDynOurCityReq\x12\x0f\n\x07\x63ity_id\x18\x01 \x01(\x03\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x16\n\x0eteenagers_mode\x18\x06 \x01(\x05\x12\n\n\x02qn\x18\x07 \x01(\x05\x12\r\n\x05\x66nver\x18\x08 \x01(\x05\x12\r\n\x05\x66nval\x18\t \x01(\x05\x12\x12\n\nforce_host\x18\n \x01(\x05\x12\r\n\x05\x66ourk\x18\x0b \x01(\x05\x12\x11\n\tlbs_state\x18\x0c \x01(\x05\x12\x14\n\x0crefresh_city\x18\r \x01(\r\x12\x32\n\x08\x65xp_conf\x18\x0e \x01(\x0b\x32 .bilibili.app.dynamic.v1.ExpConf\x12\x43\n\x0bplayer_args\x18\x0f \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x11\n\tcity_code\x18\x10 \x01(\x03\x12\x12\n\nbuild_time\x18\x11 \x01(\x03\"%\n\x13\x44ynOurCitySwitchReq\x12\x0e\n\x06switch\x18\x01 \x01(\x05\"\x1b\n\nDynRedItem\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\"\xa8\x01\n\x0b\x44ynRedReply\x12\x10\n\x08red_type\x18\x01 \x01(\t\x12\x39\n\x0c\x64yn_red_item\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v1.DynRedItem\x12\x13\n\x0b\x64\x65\x66\x61ult_tab\x18\x03 \x01(\t\x12\x37\n\tred_style\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v1.DynRedStyle\"C\n\tDynRedReq\x12\x36\n\ntab_offset\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v1.TabOffset\"\xa0\x01\n\x0b\x44ynRedStyle\x12\x0f\n\x07\x62g_type\x18\x01 \x01(\x05\x12\x13\n\x0b\x63orner_type\x18\x02 \x01(\x05\x12\x14\n\x0c\x64isplay_time\x18\x03 \x01(\x05\x12\x13\n\x0b\x63orner_mark\x18\x04 \x01(\t\x12\x32\n\x02up\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v1.DynRedStyleUp\x12\x0c\n\x04type\x18\x06 \x01(\x05\"*\n\rDynRedStyleUp\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\"\xe7\x01\n\x06\x44ynTab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06\x62ubble\x18\x03 \x01(\t\x12\x11\n\tred_point\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ity_id\x18\x05 \x01(\x03\x12\x10\n\x08is_popup\x18\x06 \x01(\x05\x12-\n\x05popup\x18\x07 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v1.Popup\x12\x12\n\ndefaultTab\x18\x08 \x01(\x08\x12\x11\n\tsub_title\x18\t \x01(\t\x12\x0e\n\x06\x61nchor\x18\n \x01(\t\x12\x15\n\rinternal_test\x18\x0b \x01(\t\"?\n\x0b\x44ynTabReply\x12\x30\n\x07\x64yn_tab\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.DynTab\"#\n\tDynTabReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\"8\n\x0f\x44ynUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\"\x82\x01\n\x15\x44ynVideoPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x05\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\"\xbe\x01\n\x13\x44ynVideoPersonalReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x10\n\x08host_uid\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x12\n\nis_preload\x18\x05 \x01(\x05\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\"\xbf\x01\n\x0b\x44ynVideoReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x17\n\x0fupdate_baseline\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x14\n\x0crefresh_type\x18\x05 \x01(\x05\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\"\x9d\x01\n\x10\x44ynVideoReqReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x05\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x05\"*\n\x03\x45xp\x12\x10\n\x08\x65xp_name\x18\x01 \x01(\t\x12\x11\n\texp_group\x18\x02 \x01(\t\"I\n\x07\x45xpConf\x12\x12\n\nexp_enable\x18\x01 \x01(\x05\x12*\n\x04\x65xps\x18\x02 \x03(\x0b\x32\x1c.bilibili.app.dynamic.v1.Exp\"\x9a\x02\n\x06\x45xtend\x12\x0c\n\x04type\x18\x01 \x01(\t\x12?\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ExtInfoTopicH\x00\x12;\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ExtInfoLBSH\x00\x12;\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ExtInfoHotH\x00\x12=\n\rext_info_game\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v1.ExtInfoGameH\x00\x42\x08\n\x06\x65xtend\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"~\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12.\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v1.NewEP\"\x98\x01\n\rGeoCoderReply\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x44\n\x11\x61\x64\x64ress_component\x18\x02 \x01(\x0b\x32).bilibili.app.dynamic.v1.AddressComponent\x12\x30\n\x07\x61\x64_info\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v1.AdInfo\"5\n\x0bGeoCoderReq\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"\x1f\n\x03Gps\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"V\n\x08LikeInfo\x12\x39\n\tanimation\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v1.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x05\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"*\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xec\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12=\n\tlive_info\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v1.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v1.VipInfo\x12\x33\n\x08relation\x18\t \x01(\x0b\x32!.bilibili.app.dynamic.v1.Relation\x12\x16\n\x0epremiere_state\x18\n \x01(\x05\x12\x0b\n\x03uri\x18\x0b \x01(\t\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xf7\x05\n\x06Module\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12:\n\x0bmodule_fold\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ModuleFoldH\x00\x12>\n\rmodule_author\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ModuleAuthorH\x00\x12@\n\x0emodule_dynamic\x18\x04 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleDynamicH\x00\x12<\n\x0cmodule_state\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v1.ModuleStateH\x00\x12@\n\x0emodule_forward\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleForwardH\x00\x12>\n\rmodule_extend\x18\x07 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ModuleExtendH\x00\x12@\n\x0emodule_dispute\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleDisputeH\x00\x12:\n\x0bmodule_desc\x18\t \x01(\x0b\x32#.bilibili.app.dynamic.v1.ModuleDescH\x00\x12\x42\n\x0fmodule_likeUser\x18\n \x01(\x0b\x32\'.bilibili.app.dynamic.v1.ModuleLikeUserH\x00\x12\x41\n\rmodule_upList\x18\x0b \x01(\x0b\x32(.bilibili.app.dynamic.v1.ModuleDynUpListH\x00\x12\x46\n\x11module_followList\x18\x0c \x01(\x0b\x32).bilibili.app.dynamic.v1.ModuleFollowListH\x00\x42\r\n\x0bmodule_item\"\xa5\x01\n\x0cModuleAuthor\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x31\n\x06\x61uthor\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v1.UserInfo\x12<\n\rdecorate_card\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v1.DecorateCard\"@\n\nModuleDesc\x12\x32\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.Description\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x9e\x02\n\rModuleDynamic\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x34\n\x08\x63\x61rd_ugc\x18\x02 \x01(\x0b\x32 .bilibili.app.dynamic.v1.CardUGCH\x00\x12\x34\n\x08\x63\x61rd_pgc\x18\x03 \x01(\x0b\x32 .bilibili.app.dynamic.v1.CardPGCH\x00\x12\x43\n\x10\x63\x61rd_curr_season\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.CardCurrSeasonH\x00\x12\x41\n\x0f\x63\x61rd_curr_batch\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v1.CardCurrBatchH\x00\x42\x06\n\x04\x63\x61rd\"l\n\x0fModuleDynUpList\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\x10\n\x08show_all\x18\x02 \x01(\t\x12\x31\n\x04list\x18\x03 \x03(\x0b\x32#.bilibili.app.dynamic.v1.UpListItem\"?\n\x0cModuleExtend\x12/\n\x06\x65xtend\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Extend\"\xaf\x01\n\nModuleFold\x12\x11\n\tfold_type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x35\n\nfold_users\x18\x04 \x03(\x0b\x32!.bilibili.app.dynamic.v1.UserInfo\x12\x37\n\x0c\x66old_type_v2\x18\x05 \x01(\x0e\x32!.bilibili.app.dynamic.v1.FoldType\"`\n\x10ModuleFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x35\n\x04list\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.FollowListItem\"T\n\rModuleForward\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x30\n\x07modules\x18\x02 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Module\"]\n\x0eModuleLikeUser\x12\x35\n\nlike_users\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v1.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"\x98\x01\n\x0bModuleState\x12\x0e\n\x06repost\x18\x01 \x01(\x05\x12\x0c\n\x04like\x18\x02 \x01(\x05\x12\r\n\x05reply\x18\x03 \x01(\x05\x12\x34\n\tlike_info\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v1.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\t\n\x07NoReply\"\x07\n\x05NoReq\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\"\x19\n\x17OurCityClickReportReply\"V\n\x15OurCityClickReportReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ity_id\x18\x02 \x01(\x03\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lng\x18\x04 \x01(\x01\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"b\n\x13PlayerPreloadParams\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"1\n\x05Popup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"z\n\x08Relation\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v1.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"q\n\tShareInfo\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0b\n\x03mid\x18\x06 \x01(\x03\x12\x0c\n\x04name\x18\x07 \x01(\t\"z\n\nSVideoItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x36\n\x07modules\x18\x02 \x03(\x0b\x32%.bilibili.app.dynamic.v1.SVideoModule\x12\x12\n\ndyn_id_str\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x03\"\xc2\x02\n\x0cSVideoModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x44\n\rmodule_author\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v1.SVideoModuleAuthorH\x00\x12\x44\n\rmodule_player\x18\x03 \x01(\x0b\x32+.bilibili.app.dynamic.v1.SVideoModulePlayerH\x00\x12@\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32).bilibili.app.dynamic.v1.SVideoModuleDescH\x00\x12@\n\x0bmodule_stat\x18\x05 \x01(\x0b\x32).bilibili.app.dynamic.v1.SVideoModuleStatH\x00\x42\r\n\x0bmodule_item\"r\n\x12SVideoModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x10\n\x08pub_desc\x18\x04 \x01(\t\x12\x14\n\x0cis_attention\x18\x05 \x01(\x05\x12\x0b\n\x03uri\x18\x06 \x01(\t\"-\n\x10SVideoModuleDesc\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xa2\x01\n\x12SVideoModulePlayer\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0b\n\x03\x63id\x18\x05 \x01(\x03\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\x35\n\tdimension\x18\x07 \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\"\x86\x01\n\x10SVideoModuleStat\x12:\n\tstat_info\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.SVideoStatInfo\x12\x36\n\nshare_info\x18\x02 \x01(\x0b\x32\".bilibili.app.dynamic.v1.ShareInfo\"\x93\x01\n\x0bSVideoReply\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v1.SVideoItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x05\x12/\n\x03top\x18\x04 \x01(\x0b\x32\".bilibili.app.dynamic.v1.SVideoTop\"\xe9\x02\n\tSVideoReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.bilibili.app.dynamic.v1.SVideoType\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\n\n\x02qn\x18\x04 \x01(\x05\x12\r\n\x05\x66nver\x18\x05 \x01(\x05\x12\r\n\x05\x66nval\x18\x06 \x01(\x05\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x05\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x44\n\x0eplayer_preload\x18\x0b \x01(\x0b\x32,.bilibili.app.dynamic.v1.PlayerPreloadParams\x12\x11\n\tfocus_aid\x18\x0c \x01(\x03\x12\x43\n\x0bplayer_args\x18\r \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"J\n\x0eSVideoStatInfo\x12\x0c\n\x04icon\x18\x01 \x01(\x05\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x10\n\x08selected\x18\x03 \x01(\x05\x12\x0b\n\x03uri\x18\x04 \x01(\t\"(\n\tSVideoTop\x12\r\n\x05Title\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x65sc\x18\x02 \x01(\t\"(\n\tTabOffset\x12\x0b\n\x03tab\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\t\"I\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x05\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\"\xc9\x02\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x39\n\x08official\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.OfficialVerify\x12-\n\x03vip\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v1.VipInfo\x12/\n\x04live\x18\x06 \x01(\x0b\x32!.bilibili.app.dynamic.v1.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x35\n\x07pendant\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v1.UserPendant\x12\x35\n\tnameplate\x18\t \x01(\x0b\x32\".bilibili.app.dynamic.v1.Nameplate\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\"\xb6\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\"\x7f\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v1.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\"\x18\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t*/\n\x06\x42gType\x12\x13\n\x0f\x62g_type_default\x10\x00\x12\x10\n\x0c\x62g_type_face\x10\x01*S\n\nCornerType\x12\x14\n\x10\x63orner_type_none\x10\x00\x12\x14\n\x10\x63orner_type_text\x10\x01\x12\x19\n\x15\x63orner_type_animation\x10\x02*m\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZero\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05*L\n\tStyleType\x12\x13\n\x0fSTYLE_TYPE_NONE\x10\x00\x12\x13\n\x0fSTYLE_TYPE_LIVE\x10\x01\x12\x15\n\x11STYLE_TYPE_DYN_UP\x10\x02*Y\n\nSVideoType\x12\x0c\n\x08TypeNone\x10\x00\x12\x0f\n\x0bTypeDynamic\x10\x01\x12\x14\n\x10TypePopularIndex\x10\x02\x12\x16\n\x12TypePopularHotword\x10\x03*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05\x32\x8a\n\n\x07\x44ynamic\x12[\n\x08\x44ynVideo\x12$.bilibili.app.dynamic.v1.DynVideoReq\x1a).bilibili.app.dynamic.v1.DynVideoReqReply\x12^\n\nDynDetails\x12&.bilibili.app.dynamic.v1.DynDetailsReq\x1a(.bilibili.app.dynamic.v1.DynDetailsReply\x12R\n\x06SVideo\x12\".bilibili.app.dynamic.v1.SVideoReq\x1a$.bilibili.app.dynamic.v1.SVideoReply\x12R\n\x06\x44ynTab\x12\".bilibili.app.dynamic.v1.DynTabReq\x1a$.bilibili.app.dynamic.v1.DynTabReply\x12\x62\n\x10\x44ynOurCitySwitch\x12,.bilibili.app.dynamic.v1.DynOurCitySwitchReq\x1a .bilibili.app.dynamic.v1.NoReply\x12^\n\nDynOurCity\x12&.bilibili.app.dynamic.v1.DynOurCityReq\x1a(.bilibili.app.dynamic.v1.DynOurCityReply\x12p\n\x10\x44ynVideoPersonal\x12,.bilibili.app.dynamic.v1.DynVideoPersonalReq\x1a..bilibili.app.dynamic.v1.DynVideoPersonalReply\x12Z\n\x0c\x44ynUpdOffset\x12(.bilibili.app.dynamic.v1.DynUpdOffsetReq\x1a .bilibili.app.dynamic.v1.NoReply\x12R\n\x06\x44ynRed\x12\".bilibili.app.dynamic.v1.DynRedReq\x1a$.bilibili.app.dynamic.v1.DynRedReply\x12j\n\x14\x44ynMixUpListViewMore\x12\x1e.bilibili.app.dynamic.v1.NoReq\x1a\x32.bilibili.app.dynamic.v1.DynMixUpListViewMoreReply\x12v\n\x12\x44ynMixUpListSearch\x12..bilibili.app.dynamic.v1.DynMixUpListSearchReq\x1a\x30.bilibili.app.dynamic.v1.DynMixUpListSearchReply\x12v\n\x12OurCityClickReport\x12..bilibili.app.dynamic.v1.OurCityClickReportReq\x1a\x30.bilibili.app.dynamic.v1.OurCityClickReportReply\x12X\n\x08GeoCoder\x12$.bilibili.app.dynamic.v1.GeoCoderReq\x1a&.bilibili.app.dynamic.v1.GeoCoderReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.dynamic.v1.dynamic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BGTYPE._serialized_start=12812
  _BGTYPE._serialized_end=12859
  _CORNERTYPE._serialized_start=12861
  _CORNERTYPE._serialized_end=12944
  _FOLDTYPE._serialized_start=12946
  _FOLDTYPE._serialized_end=13055
  _MEDIATYPE._serialized_start=13057
  _MEDIATYPE._serialized_end=13160
  _RELATIONSTATUS._serialized_start=13163
  _RELATIONSTATUS._serialized_end=13358
  _STYLETYPE._serialized_start=13360
  _STYLETYPE._serialized_end=13436
  _SVIDEOTYPE._serialized_start=13438
  _SVIDEOTYPE._serialized_end=13527
  _VIDEOSUBTYPE._serialized_start=13530
  _VIDEOSUBTYPE._serialized_end=13695
  _ADDRESSCOMPONENT._serialized_start=116
  _ADDRESSCOMPONENT._serialized_end=239
  _ADINFO._serialized_start=241
  _ADINFO._serialized_end=362
  _CARDCURRBATCH._serialized_start=365
  _CARDCURRBATCH._serialized_end=507
  _CARDCURRSEASON._serialized_start=510
  _CARDCURRSEASON._serialized_end=651
  _CARDPGC._serialized_start=654
  _CARDPGC._serialized_end=1156
  _CARDUGC._serialized_start=1159
  _CARDUGC._serialized_end=1500
  _DECOCARDFAN._serialized_start=1502
  _DECOCARDFAN._serialized_end=1562
  _DECORATECARD._serialized_start=1564
  _DECORATECARD._serialized_end=1677
  _DESCRIPTION._serialized_start=1679
  _DESCRIPTION._serialized_end=1773
  _DIMENSION._serialized_start=1775
  _DIMENSION._serialized_end=1833
  _DYNAMICITEM._serialized_start=1836
  _DYNAMICITEM._serialized_end=2016
  _DYNDETAILSREPLY._serialized_start=2018
  _DYNDETAILSREPLY._serialized_end=2087
  _DYNDETAILSREQ._serialized_start=2090
  _DYNDETAILSREQ._serialized_end=2227
  _DYNMIXUPLISTSEARCHREPLY._serialized_start=2229
  _DYNMIXUPLISTSEARCHREPLY._serialized_end=2309
  _DYNMIXUPLISTSEARCHREQ._serialized_start=2311
  _DYNMIXUPLISTSEARCHREQ._serialized_end=2348
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_start=2350
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_end=2461
  _DYNOURCITYITEM._serialized_start=2464
  _DYNOURCITYITEM._serialized_end=2621
  _DYNOURCITYMODULE._serialized_start=2624
  _DYNOURCITYMODULE._serialized_end=2968
  _DYNOURCITYMODULEAUTHOR._serialized_start=2970
  _DYNOURCITYMODULEAUTHOR._serialized_end=3048
  _DYNOURCITYMODULECOVER._serialized_start=3051
  _DYNOURCITYMODULECOVER._serialized_end=3292
  _DYNOURCITYMODULEDESC._serialized_start=3294
  _DYNOURCITYMODULEDESC._serialized_end=3330
  _DYNOURCITYMODULEEXTEND._serialized_start=3332
  _DYNOURCITYMODULEEXTEND._serialized_end=3454
  _DYNOURCITYMODULEEXTENDLBS._serialized_start=3456
  _DYNOURCITYMODULEEXTENDLBS._serialized_end=3543
  _DYNOURCITYREPLY._serialized_start=3546
  _DYNOURCITYREPLY._serialized_end=3748
  _DYNOURCITYREQ._serialized_start=3751
  _DYNOURCITYREQ._serialized_end=4146
  _DYNOURCITYSWITCHREQ._serialized_start=4148
  _DYNOURCITYSWITCHREQ._serialized_end=4185
  _DYNREDITEM._serialized_start=4187
  _DYNREDITEM._serialized_end=4214
  _DYNREDREPLY._serialized_start=4217
  _DYNREDREPLY._serialized_end=4385
  _DYNREDREQ._serialized_start=4387
  _DYNREDREQ._serialized_end=4454
  _DYNREDSTYLE._serialized_start=4457
  _DYNREDSTYLE._serialized_end=4617
  _DYNREDSTYLEUP._serialized_start=4619
  _DYNREDSTYLEUP._serialized_end=4661
  _DYNTAB._serialized_start=4664
  _DYNTAB._serialized_end=4895
  _DYNTABREPLY._serialized_start=4897
  _DYNTABREPLY._serialized_end=4960
  _DYNTABREQ._serialized_start=4962
  _DYNTABREQ._serialized_end=4997
  _DYNUPDOFFSETREQ._serialized_start=4999
  _DYNUPDOFFSETREQ._serialized_end=5055
  _DYNVIDEOPERSONALREPLY._serialized_start=5058
  _DYNVIDEOPERSONALREPLY._serialized_end=5188
  _DYNVIDEOPERSONALREQ._serialized_start=5191
  _DYNVIDEOPERSONALREQ._serialized_end=5381
  _DYNVIDEOREQ._serialized_start=5384
  _DYNVIDEOREQ._serialized_end=5575
  _DYNVIDEOREQREPLY._serialized_start=5578
  _DYNVIDEOREQREPLY._serialized_end=5735
  _EXP._serialized_start=5737
  _EXP._serialized_end=5779
  _EXPCONF._serialized_start=5781
  _EXPCONF._serialized_end=5854
  _EXTEND._serialized_start=5857
  _EXTEND._serialized_end=6139
  _EXTINFOGAME._serialized_start=6141
  _EXTINFOGAME._serialized_end=6196
  _EXTINFOHOT._serialized_start=6198
  _EXTINFOHOT._serialized_end=6252
  _EXTINFOLBS._serialized_start=6254
  _EXTINFOLBS._serialized_end=6326
  _EXTINFOTOPIC._serialized_start=6328
  _EXTINFOTOPIC._serialized_end=6384
  _FOLLOWLISTITEM._serialized_start=6386
  _FOLLOWLISTITEM._serialized_end=6512
  _GEOCODERREPLY._serialized_start=6515
  _GEOCODERREPLY._serialized_end=6667
  _GEOCODERREQ._serialized_start=6669
  _GEOCODERREQ._serialized_end=6722
  _GPS._serialized_start=6724
  _GPS._serialized_end=6755
  _LIKEANIMATION._serialized_start=6757
  _LIKEANIMATION._serialized_end=6836
  _LIKEINFO._serialized_start=6838
  _LIKEINFO._serialized_end=6924
  _LIKEUSER._serialized_start=6926
  _LIKEUSER._serialized_end=6977
  _LIVEINFO._serialized_start=6979
  _LIVEINFO._serialized_end=7021
  _MIXUPLISTITEM._serialized_start=7024
  _MIXUPLISTITEM._serialized_end=7388
  _MIXUPLISTLIVEITEM._serialized_start=7390
  _MIXUPLISTLIVEITEM._serialized_end=7455
  _MODULE._serialized_start=7458
  _MODULE._serialized_end=8217
  _MODULEAUTHOR._serialized_start=8220
  _MODULEAUTHOR._serialized_end=8385
  _MODULEDESC._serialized_start=8387
  _MODULEDESC._serialized_end=8451
  _MODULEDISPUTE._serialized_start=8453
  _MODULEDISPUTE._serialized_end=8510
  _MODULEDYNAMIC._serialized_start=8513
  _MODULEDYNAMIC._serialized_end=8799
  _MODULEDYNUPLIST._serialized_start=8801
  _MODULEDYNUPLIST._serialized_end=8909
  _MODULEEXTEND._serialized_start=8911
  _MODULEEXTEND._serialized_end=8974
  _MODULEFOLD._serialized_start=8977
  _MODULEFOLD._serialized_end=9152
  _MODULEFOLLOWLIST._serialized_start=9154
  _MODULEFOLLOWLIST._serialized_end=9250
  _MODULEFORWARD._serialized_start=9252
  _MODULEFORWARD._serialized_end=9336
  _MODULELIKEUSER._serialized_start=9338
  _MODULELIKEUSER._serialized_end=9431
  _MODULESTATE._serialized_start=9434
  _MODULESTATE._serialized_end=9586
  _NAMEPLATE._serialized_start=9588
  _NAMEPLATE._serialized_end=9696
  _NEWEP._serialized_start=9698
  _NEWEP._serialized_end=9752
  _NOREPLY._serialized_start=9754
  _NOREPLY._serialized_end=9763
  _NOREQ._serialized_start=9765
  _NOREQ._serialized_end=9772
  _OFFICIALVERIFY._serialized_start=9774
  _OFFICIALVERIFY._serialized_end=9836
  _OURCITYCLICKREPORTREPLY._serialized_start=9838
  _OURCITYCLICKREPORTREPLY._serialized_end=9863
  _OURCITYCLICKREPORTREQ._serialized_start=9865
  _OURCITYCLICKREPORTREQ._serialized_end=9951
  _PGCSEASON._serialized_start=9953
  _PGCSEASON._serialized_end=10012
  _PLAYERPRELOADPARAMS._serialized_start=10014
  _PLAYERPRELOADPARAMS._serialized_end=10112
  _POPUP._serialized_start=10114
  _POPUP._serialized_end=10163
  _RELATION._serialized_start=10165
  _RELATION._serialized_end=10287
  _SHAREINFO._serialized_start=10289
  _SHAREINFO._serialized_end=10402
  _SVIDEOITEM._serialized_start=10404
  _SVIDEOITEM._serialized_end=10526
  _SVIDEOMODULE._serialized_start=10529
  _SVIDEOMODULE._serialized_end=10851
  _SVIDEOMODULEAUTHOR._serialized_start=10853
  _SVIDEOMODULEAUTHOR._serialized_end=10967
  _SVIDEOMODULEDESC._serialized_start=10969
  _SVIDEOMODULEDESC._serialized_end=11014
  _SVIDEOMODULEPLAYER._serialized_start=11017
  _SVIDEOMODULEPLAYER._serialized_end=11179
  _SVIDEOMODULESTAT._serialized_start=11182
  _SVIDEOMODULESTAT._serialized_end=11316
  _SVIDEOREPLY._serialized_start=11319
  _SVIDEOREPLY._serialized_end=11466
  _SVIDEOREQ._serialized_start=11469
  _SVIDEOREQ._serialized_end=11830
  _SVIDEOSTATINFO._serialized_start=11832
  _SVIDEOSTATINFO._serialized_end=11906
  _SVIDEOTOP._serialized_start=11908
  _SVIDEOTOP._serialized_end=11948
  _TABOFFSET._serialized_start=11950
  _TABOFFSET._serialized_end=11990
  _UPLISTITEM._serialized_start=11992
  _UPLISTITEM._serialized_end=12065
  _USERINFO._serialized_start=12068
  _USERINFO._serialized_end=12397
  _USERPENDANT._serialized_start=12399
  _USERPENDANT._serialized_end=12470
  _VIDEOBADGE._serialized_start=12473
  _VIDEOBADGE._serialized_end=12655
  _VIPINFO._serialized_start=12657
  _VIPINFO._serialized_end=12784
  _VIPLABEL._serialized_start=12786
  _VIPLABEL._serialized_end=12810
  _DYNAMIC._serialized_start=13698
  _DYNAMIC._serialized_end=14988
# @@protoc_insertion_point(module_scope)
